@@ -2,9 +2,9 @@
     orzmdi
     copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,20 +13,12 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "orzmdi.h"
 #include "misc/fileio.h"
 
 
-static void orz_mdi_class_init (OrzMdiClass *klass);
-static void orz_mdi_init       (OrzMdi      *mdi);
-
-
-static GtkNotebookClass *parent_class = NULL;
-
-
 enum
 {
   ADD_WINDOW_SIGNAL,
@@ -37,8 +29,6 @@ enum
   SWITCH_WINDOW_SIGNAL,
   LAST_SIGNAL
 };
-
-
 enum
 {
   TARGET_ORZ_MDI_TAB
@@ -244,32 +234,7 @@ file_remove_edit (OrzMdi      *mdi,
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
-GtkType
-orz_mdi_get_type (void)
-{
-  static GType orz_mdi_type = 0;
-
-  if (!orz_mdi_type)
-    {
-      const static GTypeInfo mdi_info =
-      {
-        sizeof (OrzMdiClass),
-        NULL,               /* base_init */
-        NULL,               /* base_finalize */
-        (GClassInitFunc)orz_mdi_class_init,
-        NULL,               /* class_finalize */
-        NULL,               /* class_data */
-        sizeof (OrzMdi),
-        0,                  /* n_preallocs */
-        (GInstanceInitFunc)orz_mdi_init,
-      };
-
-      orz_mdi_type = g_type_register_static (GTK_TYPE_NOTEBOOK, "OrzMdi",
-                                                                &mdi_info, 0);
-    }
-
-  return orz_mdi_type;
-}
+G_DEFINE_TYPE (OrzMdi, orz_mdi, GTK_TYPE_NOTEBOOK);
 
 
 /* ja:子ウィジェットが破棄されるとき */
@@ -295,7 +260,7 @@ orz_mdi_remove (GtkContainer *container,
           file_remove_edit (ORZ_MDI (container), tab, NULL);
         }
     }
-  ((GtkContainerClass *)parent_class)->remove (container, widget);
+  GTK_CONTAINER_CLASS (orz_mdi_parent_class)->remove (container, widget);
 }
 
 
@@ -306,7 +271,8 @@ orz_mdi_switch_page (GtkNotebook     *notebook,
 {
   GtkWidget *child;
 
-  parent_class->switch_page (notebook, page, page_num);
+  GTK_NOTEBOOK_CLASS (orz_mdi_parent_class)->switch_page
+                                                    (notebook, page, page_num);
   child = gtk_notebook_get_nth_page (notebook, page_num);
   if (child)
     {
@@ -335,11 +301,9 @@ orz_mdi_class_init (OrzMdiClass *klass)
   GtkContainerClass *container_class;
   GtkNotebookClass *notebook_class;
 
-  container_class = (GtkContainerClass *) klass;
-  notebook_class = (GtkNotebookClass *) klass;
-
-  parent_class = g_type_class_peek_parent (klass);
+  container_class = GTK_CONTAINER_CLASS (klass);
   container_class->remove = orz_mdi_remove;
+  notebook_class = GTK_NOTEBOOK_CLASS (klass);
   notebook_class->switch_page = orz_mdi_switch_page;
 
   klass->add_window = NULL;
