@@ -455,7 +455,7 @@ file_open_edit (const gchar *file)
   gtk_widget_add_events (tmaid->drawing, GDK_POINTER_MOTION_MASK
                             | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
                             | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK
-                            | GDK_FOCUS_CHANGE_MASK);
+                            | GDK_FOCUS_CHANGE_MASK | GDK_SCROLL_MASK);
   GTK_WIDGET_SET_FLAGS (tmaid->drawing, GTK_CAN_FOCUS);
   /* ja:フォント */
   if (tmaid->ft.font_name)
