@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -384,7 +384,7 @@ signal_key_press (GtkWidget   *widget,
 
           if (!(event->state & (GDK_CONTROL_MASK | GDK_MOD1_MASK)))
             {
-              select=tmaid->select;
+              select = tmaid->select;
               if (tmaid->ft.tabconv ^ ((event->state & GDK_SHIFT_MASK) != 0))
                 {
                   align_pos = edit_get_align_pos (tmaid,
@@ -399,7 +399,7 @@ signal_key_press (GtkWidget   *widget,
                 {
                   d = edit_operation (tmaid, "\t", 1, TRUE, FALSE);
                 }
-              d->next=tmaid->undo;
+              d->next = tmaid->undo;
               tmaid->undo = d;
               if (delete_list (&tmaid->redo) > 0 || !d->next || select.x >= 0)
                 set_menu_bar (tmaid);
@@ -415,15 +415,15 @@ signal_key_press (GtkWidget   *widget,
               page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
               if (event->state & GDK_SHIFT_MASK)
                 {
-                  if (--page<0)
-                    page=length-1;
+                  if (--page < 0)
+                    page = length - 1;
                 }
               else
                 {
-                  if (++page>=length)
-                    page=0;
+                  if (++page >= length)
+                    page = 0;
                 }
-              gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page);
+              gtk_notebook_set_current_page (GTK_NOTEBOOK (mdi), page);
               gtk_widget_grab_focus (((TmaidWindow *)
                             orz_mdi_get_data (ORZ_MDI (mdi), page))->drawing);
             }
