@@ -92,7 +92,7 @@ signal_style_set (GtkWidget *widget,
                     MAX (tmaid->drawing->allocation.height
                                     / tmaid->font_height, 1), tmaid->top.y);
             }
-          gtk_widget_draw (tmaid->drawing, NULL);/* ja:再描画 */
+          gtk_widget_queue_draw (tmaid->drawing);/* ja:再描画 */
         }
     }
 }
@@ -140,7 +140,7 @@ void
 signal_destroy_mdi (GtkWidget *widget,
                     gpointer   user_data)
 {
-  gtk_timeout_remove (timer_id);
+  g_source_remove (timer_id);
 }
 
 
