@@ -478,7 +478,7 @@ main (int   argc,
   if (license_hash (gnugpl) != license)
     license = license_dialog (gnugpl);
   if (license < 0)
-    gtk_exit (0);
+    return 0;
 
   /* ja:コマンドライン */
   /* ja:ファイルの履歴 */
@@ -683,7 +683,7 @@ TMAID_COPYRIGHT_NOTICE"\n"
       if (!orz_comm_is_first (ORZ_COMM (comm)))
         {
           orz_comm_send_with_files (ORZ_COMM (comm), argc, argv, arg_files);
-          gtk_exit (0);
+          return 0;
         }
       g_signal_connect (G_OBJECT (comm), "recv",
                                     G_CALLBACK (signal_selection_recv), NULL);
