@@ -1,10 +1,10 @@
 /*
     Text maid
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #ifndef __TMAID_H__
 #define __TMAID_H__
@@ -24,13 +23,11 @@
 #include "misc/misc.h"
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 
 #define TMAID_VERSION_NOTICE "Text maid "VERSION" ("BUILD_ENVIRONMENT")"
-#define TMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2007 Kazuki IWAMOTO"
+#define TMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2008 Kazuki IWAMOTO"
 
 
 typedef struct _FileType
@@ -144,9 +141,7 @@ extern MiscCreateMenuEntry popup_entries[];
 extern MiscCreateToolbarEntry toolbar_entries[];
 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 
 #endif /* __TMAID_H__ */
